@@ -12,7 +12,10 @@
 #define _GNU_SOURCE
 
 #include "src/compiled.h"          /* GAP headers                */
-#include "src/iostream.h"          /* Signal Handling            */
+
+#if GAP_KERNEL_MAJOR_VERSION >= 6
+#include "src/profile.h"
+#endif
 
 #undef PACKAGE
 #undef PACKAGE_BUGREPORT
@@ -226,7 +229,7 @@ RETSIGTYPE IO_SIGCHLDHandler( int whichsig )
   signal(SIGCHLD, IO_SIGCHLDHandler);
 }
 
-Obj FuncIO_InstallSIGCHLDHandler( Obj self )
+static Obj FuncIO_InstallSIGCHLDHandler( Obj self )
 {
   /* Do not install ourselves twice: */
   if (oldhandler == 0) {
@@ -237,7 +240,7 @@ Obj FuncIO_InstallSIGCHLDHandler( Obj self )
       return False;
 }
 
-Obj FuncIO_RestoreSIGCHLDHandler( Obj self )
+static Obj FuncIO_RestoreSIGCHLDHandler( Obj self )
 {
   if (oldhandler == 0)
       return False;
@@ -268,7 +271,7 @@ static int IO_CheckForIgnoredPid( int pid )
     return found;
 }
 
-Obj FuncIO_IgnorePid(Obj self, Obj pid)
+static Obj FuncIO_IgnorePid(Obj self, Obj pid)
 {
     Int pidc;
     int pos;
@@ -306,7 +309,7 @@ Obj FuncIO_IgnorePid(Obj self, Obj pid)
     return True;
 }
 
-Obj FuncIO_WaitPid(Obj self,Obj pid,Obj wait)
+static Obj FuncIO_WaitPid(Obj self,Obj pid,Obj wait)
 {
   Int pidc;
   int pos;
@@ -349,15 +352,15 @@ Obj FuncIO_WaitPid(Obj self,Obj pid,Obj wait)
 }
 #endif
 
-Obj FuncIO_open(Obj self,Obj path,Obj flags,Obj mode)
+static Obj FuncIO_open(Obj self,Obj path,Obj flags,Obj mode)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path) || !IS_INTOBJ(flags) ||
       !IS_INTOBJ(mode) ) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = open((char *) CHARS_STRING(path),
+      res = open(CSTR_STRING(path),
                  INT_INTOBJ(flags),INT_INTOBJ(mode));
       if (res < 0) {
           SySetErrorNo();
@@ -367,14 +370,14 @@ Obj FuncIO_open(Obj self,Obj path,Obj flags,Obj mode)
   }
 }
 
-Obj FuncIO_creat(Obj self,Obj path,Obj mode)
+static Obj FuncIO_creat(Obj self,Obj path,Obj mode)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path) || !IS_INTOBJ(mode) ) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = creat((char *) CHARS_STRING(path),INT_INTOBJ(mode));
+      res = creat(CSTR_STRING(path),INT_INTOBJ(mode));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -383,7 +386,7 @@ Obj FuncIO_creat(Obj self,Obj path,Obj mode)
   }
 }
 
-Obj FuncIO_read(Obj self,Obj fd,Obj st,Obj offset,Obj count)
+static Obj FuncIO_read(Obj self,Obj fd,Obj st,Obj offset,Obj count)
 {
   Int bytes;
   Int len;
@@ -410,7 +413,7 @@ Obj FuncIO_read(Obj self,Obj fd,Obj st,Obj offset,Obj count)
   }
 }
 
-Obj FuncIO_write(Obj self,Obj fd,Obj st,Obj offset,Obj count)
+static Obj FuncIO_write(Obj self,Obj fd,Obj st,Obj offset,Obj count)
 {
   Int bytes;
 
@@ -432,9 +435,9 @@ Obj FuncIO_write(Obj self,Obj fd,Obj st,Obj offset,Obj count)
       return INTOBJ_INT(bytes);
 }
 
-Obj FuncIO_close(Obj self,Obj fd)
+static Obj FuncIO_close(Obj self,Obj fd)
 {
-  Int res;
+  int res;
 
   if (!IS_INTOBJ(fd)) {
       SyClearErrorNo();
@@ -449,7 +452,7 @@ Obj FuncIO_close(Obj self,Obj fd)
   }
 }
 
-Obj FuncIO_lseek(Obj self,Obj fd,Obj offset,Obj whence)
+static Obj FuncIO_lseek(Obj self,Obj fd,Obj offset,Obj whence)
 {
   Int bytes;
 
@@ -473,13 +476,13 @@ static DIR *ourDIR = 0;
 static struct dirent *ourdirent;
 
 #ifdef HAVE_OPENDIR
-Obj FuncIO_opendir(Obj self,Obj name)
+static Obj FuncIO_opendir(Obj self,Obj name)
 {
   if (!IS_STRING(name) || !IS_STRING_REP(name)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      ourDIR = opendir((char *) CHARS_STRING(name));
+      ourDIR = opendir(CSTR_STRING(name));
       if (ourDIR == 0) {
           SySetErrorNo();
           return Fail;
@@ -490,9 +493,8 @@ Obj FuncIO_opendir(Obj self,Obj name)
 #endif     /* HAVE_OPENDIR */
 
 #ifdef HAVE_READDIR
-Obj FuncIO_readdir(Obj self)
+static Obj FuncIO_readdir(Obj self)
 {
-  Obj res;
   Int olderrno;
   if (ourDIR == 0) {
       SyClearErrorNo();
@@ -510,15 +512,14 @@ Obj FuncIO_readdir(Obj self)
           return False;
       }
   }
-  C_NEW_STRING(res,strlen(ourdirent->d_name),ourdirent->d_name);
-  return res;
+  return MakeString(ourdirent->d_name);
 }
 #endif     /* HAVE_READDIR */
 
 #ifdef HAVE_CLOSEDIR
-Obj FuncIO_closedir(Obj self)
+static Obj FuncIO_closedir(Obj self)
 {
-  Int res;
+  int res;
 
   if (ourDIR == 0) {
       SyClearErrorNo();
@@ -534,7 +535,7 @@ Obj FuncIO_closedir(Obj self)
 #endif     /* HAVE_CLOSEDIR */
 
 #ifdef HAVE_REWINDDIR
-Obj FuncIO_rewinddir(Obj self)
+static Obj FuncIO_rewinddir(Obj self)
 {
   if (ourDIR == 0) {
       SyClearErrorNo();
@@ -546,7 +547,7 @@ Obj FuncIO_rewinddir(Obj self)
 #endif     /* HAVE_REWINDDIR */
 
 #ifdef HAVE_TELLDIR
-Obj FuncIO_telldir(Obj self)
+static Obj FuncIO_telldir(Obj self)
 {
   Int o;
   if (ourDIR == 0) {
@@ -563,7 +564,7 @@ Obj FuncIO_telldir(Obj self)
 #endif     /* HAVE_TELLDIR */
 
 #ifdef HAVE_SEEKDIR
-Obj FuncIO_seekdir(Obj self,Obj offset)
+static Obj FuncIO_seekdir(Obj self,Obj offset)
 {
   if (!IS_INTOBJ(offset)) {
       SyClearErrorNo();
@@ -581,14 +582,14 @@ Obj FuncIO_seekdir(Obj self,Obj offset)
 #endif     /* HAVE_DIRENT_H */
 
 #ifdef HAVE_UNLINK
-Obj FuncIO_unlink(Obj self,Obj path)
+static Obj FuncIO_unlink(Obj self,Obj path)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = unlink((char *) CHARS_STRING(path));
+      res = unlink(CSTR_STRING(path));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -599,15 +600,15 @@ Obj FuncIO_unlink(Obj self,Obj path)
 #endif
 
 #ifdef HAVE_LINK
-Obj FuncIO_link(Obj self,Obj oldpath,Obj newpath)
+static Obj FuncIO_link(Obj self,Obj oldpath,Obj newpath)
 {
-  Int res;
+  int res;
   if (!IS_STRING(oldpath) || !IS_STRING_REP(oldpath) ||
       !IS_STRING(newpath) || !IS_STRING_REP(newpath)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = link((char *) CHARS_STRING(oldpath),(char *) CHARS_STRING(newpath));
+      res = link(CSTR_STRING(oldpath),CSTR_STRING(newpath));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -618,16 +619,16 @@ Obj FuncIO_link(Obj self,Obj oldpath,Obj newpath)
 #endif
 
 #ifdef HAVE_RENAME
-Obj FuncIO_rename(Obj self,Obj oldpath,Obj newpath)
+static Obj FuncIO_rename(Obj self,Obj oldpath,Obj newpath)
 {
-  Int res;
+  int res;
   if (!IS_STRING(oldpath) || !IS_STRING_REP(oldpath) ||
       !IS_STRING(newpath) || !IS_STRING_REP(newpath)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = rename((char *) CHARS_STRING(oldpath),
-                   (char *) CHARS_STRING(newpath));
+      res = rename(CSTR_STRING(oldpath),
+                   CSTR_STRING(newpath));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -638,16 +639,16 @@ Obj FuncIO_rename(Obj self,Obj oldpath,Obj newpath)
 #endif
 
 #ifdef HAVE_SYMLINK
-Obj FuncIO_symlink(Obj self,Obj oldpath,Obj newpath)
+static Obj FuncIO_symlink(Obj self,Obj oldpath,Obj newpath)
 {
-  Int res;
+  int res;
   if (!IS_STRING(oldpath) || !IS_STRING_REP(oldpath) ||
       !IS_STRING(newpath) || !IS_STRING_REP(newpath)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = symlink((char *) CHARS_STRING(oldpath),
-                    (char *) CHARS_STRING(newpath));
+      res = symlink(CSTR_STRING(oldpath),
+                    CSTR_STRING(newpath));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -658,17 +659,17 @@ Obj FuncIO_symlink(Obj self,Obj oldpath,Obj newpath)
 #endif
 
 #ifdef HAVE_READLINK
-Obj FuncIO_readlink(Obj self,Obj path,Obj buf,Obj bufsize)
+static Obj FuncIO_readlink(Obj self,Obj path,Obj buf,Obj bufsize)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path) ||
       !IS_STRING(buf) || !IS_STRING_REP(buf) || !IS_INTOBJ(bufsize)) {
       SyClearErrorNo();
       return Fail;
   } else {
       GrowString(buf,INT_INTOBJ(bufsize));
-      res = readlink((char *) CHARS_STRING(path),
-                     (char *) CHARS_STRING(buf),INT_INTOBJ(bufsize));
+      res = readlink(CSTR_STRING(path),
+                     CSTR_STRING(buf),INT_INTOBJ(bufsize));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -681,14 +682,14 @@ Obj FuncIO_readlink(Obj self,Obj path,Obj buf,Obj bufsize)
 }
 #endif
 
-Obj FuncIO_chdir(Obj self,Obj pathname)
+static Obj FuncIO_chdir(Obj self,Obj pathname)
 {
-  Int res;
+  int res;
   if (!IS_STRING(pathname) || !IS_STRING_REP(pathname)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = chdir((char *) CHARS_STRING(pathname));
+      res = chdir(CSTR_STRING(pathname));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -697,10 +698,10 @@ Obj FuncIO_chdir(Obj self,Obj pathname)
   }
 }
 
-Obj FuncIO_getcwd(Obj self)
+static Obj FuncIO_getcwd(Obj self)
 {
   char *res;
-  char buf[MAXPATHLEN];
+  char buf[GAP_PATH_MAX];
 
   res = getcwd(buf, sizeof(buf));
   if (res == NULL) {
@@ -711,14 +712,14 @@ Obj FuncIO_getcwd(Obj self)
 }
 
 #ifdef HAVE_MKDIR
-Obj FuncIO_mkdir(Obj self,Obj pathname,Obj mode)
+static Obj FuncIO_mkdir(Obj self,Obj pathname,Obj mode)
 {
-  Int res;
+  int res;
   if (!IS_STRING(pathname) || !IS_STRING_REP(pathname) || !IS_INTOBJ(mode)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = mkdir((char *) CHARS_STRING(pathname),INT_INTOBJ(mode));
+      res = mkdir(CSTR_STRING(pathname),INT_INTOBJ(mode));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -729,14 +730,14 @@ Obj FuncIO_mkdir(Obj self,Obj pathname,Obj mode)
 #endif
 
 #ifdef HAVE_RMDIR
-Obj FuncIO_rmdir(Obj self,Obj path)
+static Obj FuncIO_rmdir(Obj self,Obj path)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = rmdir((char *) CHARS_STRING(path));
+      res = rmdir(CSTR_STRING(path));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -746,118 +747,92 @@ Obj FuncIO_rmdir(Obj self,Obj path)
 }
 #endif
 
+#if defined(HAVE_STAT) || defined(HAVE_FSTAT) || defined(HAVE_LSTAT)
+
+static Obj WrapStat(struct stat * statbuf)
+{
+    Obj rec = NEW_PREC(13);
+    AssPRec(rec, RNamName("dev"), ObjInt_UInt8(statbuf->st_dev));
+    AssPRec(rec, RNamName("ino"), ObjInt_UInt8(statbuf->st_ino));
+    AssPRec(rec, RNamName("mode"),ObjInt_UInt(statbuf->st_mode));
+    AssPRec(rec, RNamName("nlink"), ObjInt_UInt8(statbuf->st_nlink));
+    AssPRec(rec, RNamName("uid"), ObjInt_UInt(statbuf->st_uid));
+    AssPRec(rec, RNamName("gid"), ObjInt_UInt(statbuf->st_gid));
+    AssPRec(rec, RNamName("rdev"), ObjInt_UInt8(statbuf->st_rdev));
+    AssPRec(rec, RNamName("size"), ObjInt_Int8(statbuf->st_size));
+    AssPRec(rec, RNamName("blksize"), ObjInt_Int8(statbuf->st_blksize));
+    AssPRec(rec, RNamName("blocks"), ObjInt_Int8(statbuf->st_blocks));
+    AssPRec(rec, RNamName("atime"), ObjInt_Int(statbuf->st_atime));
+    AssPRec(rec, RNamName("mtime"), ObjInt_Int(statbuf->st_mtime));
+    AssPRec(rec, RNamName("ctime"), ObjInt_Int(statbuf->st_ctime));
+    return rec;
+}
+
+#endif
 
 #ifdef HAVE_STAT
-Obj FuncIO_stat(Obj self,Obj filename)
+static Obj FuncIO_stat(Obj self,Obj filename)
 {
-  struct stat ourstatbuf;
-  Int res;
-  Obj rec;
-  if (!IS_STRING(filename) || !IS_STRING_REP(filename)) {
-      SyClearErrorNo();
-      return Fail;
-  } else {
-      res = stat((char *) CHARS_STRING(filename),&ourstatbuf);
-      if (res < 0) {
+    if (!IS_STRING(filename) || !IS_STRING_REP(filename)) {
+        SyClearErrorNo();
+        return Fail;
+    }
+
+    struct stat ourstatbuf;
+    int res = stat(CSTR_STRING(filename), &ourstatbuf);
+    if (res < 0) {
         SySetErrorNo();
         return Fail;
-      }
-      rec = NEW_PREC(0);
-      AssPRec(rec,RNamName("dev"),ObjInt_Int((Int) ourstatbuf.st_dev));
-      AssPRec(rec,RNamName("ino"),ObjInt_Int((Int) ourstatbuf.st_ino));
-      AssPRec(rec,RNamName("mode"),ObjInt_Int((Int) ourstatbuf.st_mode));
-      AssPRec(rec,RNamName("nlink"),ObjInt_Int((Int) ourstatbuf.st_nlink));
-      AssPRec(rec,RNamName("uid"),ObjInt_Int((Int) ourstatbuf.st_uid));
-      AssPRec(rec,RNamName("gid"),ObjInt_Int((Int) ourstatbuf.st_gid));
-      AssPRec(rec,RNamName("rdev"),ObjInt_Int((Int) ourstatbuf.st_rdev));
-      AssPRec(rec,RNamName("size"),ObjInt_Int((Int) ourstatbuf.st_size));
-      AssPRec(rec,RNamName("blksize"),ObjInt_Int((Int)ourstatbuf.st_blksize));
-      AssPRec(rec,RNamName("blocks"),ObjInt_Int((Int) ourstatbuf.st_blocks));
-      AssPRec(rec,RNamName("atime"),ObjInt_Int((Int) ourstatbuf.st_atime));
-      AssPRec(rec,RNamName("mtime"),ObjInt_Int((Int) ourstatbuf.st_mtime));
-      AssPRec(rec,RNamName("ctime"),ObjInt_Int((Int) ourstatbuf.st_ctime));
-      return rec;
-  }
+    }
+    return WrapStat(&ourstatbuf);
 }
 #endif
 
 #ifdef HAVE_FSTAT
-Obj FuncIO_fstat(Obj self,Obj fd)
+static Obj FuncIO_fstat(Obj self,Obj fd)
 {
-  struct stat ourfstatbuf;
-  Int res;
-  Obj rec;
-  if (!IS_INTOBJ(fd)) {
-      SyClearErrorNo();
-      return Fail;
-  } else {
-      res = fstat(INT_INTOBJ(fd),&ourfstatbuf);
-      if (res < 0) {
+    if (!IS_INTOBJ(fd)) {
+        SyClearErrorNo();
+        return Fail;
+    }
+
+    struct stat ourstatbuf;
+    int res = fstat(INT_INTOBJ(fd), &ourstatbuf);
+    if (res < 0) {
         SySetErrorNo();
         return Fail;
-      }
-      rec = NEW_PREC(0);
-      AssPRec(rec,RNamName("dev"),ObjInt_Int((Int) ourfstatbuf.st_dev));
-      AssPRec(rec,RNamName("ino"),ObjInt_Int((Int) ourfstatbuf.st_ino));
-      AssPRec(rec,RNamName("mode"),ObjInt_Int((Int) ourfstatbuf.st_mode));
-      AssPRec(rec,RNamName("nlink"),ObjInt_Int((Int) ourfstatbuf.st_nlink));
-      AssPRec(rec,RNamName("uid"),ObjInt_Int((Int) ourfstatbuf.st_uid));
-      AssPRec(rec,RNamName("gid"),ObjInt_Int((Int) ourfstatbuf.st_gid));
-      AssPRec(rec,RNamName("rdev"),ObjInt_Int((Int) ourfstatbuf.st_rdev));
-      AssPRec(rec,RNamName("size"),ObjInt_Int((Int) ourfstatbuf.st_size));
-      AssPRec(rec,RNamName("blksize"),ObjInt_Int((Int)ourfstatbuf.st_blksize));
-      AssPRec(rec,RNamName("blocks"),ObjInt_Int((Int) ourfstatbuf.st_blocks));
-      AssPRec(rec,RNamName("atime"),ObjInt_Int((Int) ourfstatbuf.st_atime));
-      AssPRec(rec,RNamName("mtime"),ObjInt_Int((Int) ourfstatbuf.st_mtime));
-      AssPRec(rec,RNamName("ctime"),ObjInt_Int((Int) ourfstatbuf.st_ctime));
-      return rec;
-  }
+    }
+    return WrapStat(&ourstatbuf);
 }
 #endif
 
 #ifdef HAVE_LSTAT
-Obj FuncIO_lstat(Obj self,Obj filename)
+static Obj FuncIO_lstat(Obj self,Obj filename)
 {
-  struct stat ourlstatbuf;
-  Int res;
-  Obj rec;
-  if (!IS_STRING(filename) || !IS_STRING_REP(filename)) {
-      SyClearErrorNo();
-      return Fail;
-  } else {
-      res = lstat((char *) CHARS_STRING(filename),&ourlstatbuf);
-      if (res < 0) {
+    if (!IS_STRING(filename) || !IS_STRING_REP(filename)) {
+        SyClearErrorNo();
+        return Fail;
+    }
+
+    struct stat ourstatbuf;
+    int res = lstat(CSTR_STRING(filename), &ourstatbuf);
+    if (res < 0) {
         SySetErrorNo();
         return Fail;
-      }
-      rec = NEW_PREC(0);
-      AssPRec(rec,RNamName("dev"),ObjInt_Int((Int) ourlstatbuf.st_dev));
-      AssPRec(rec,RNamName("ino"),ObjInt_Int((Int) ourlstatbuf.st_ino));
-      AssPRec(rec,RNamName("mode"),ObjInt_Int((Int) ourlstatbuf.st_mode));
-      AssPRec(rec,RNamName("nlink"),ObjInt_Int((Int) ourlstatbuf.st_nlink));
-      AssPRec(rec,RNamName("uid"),ObjInt_Int((Int) ourlstatbuf.st_uid));
-      AssPRec(rec,RNamName("gid"),ObjInt_Int((Int) ourlstatbuf.st_gid));
-      AssPRec(rec,RNamName("rdev"),ObjInt_Int((Int) ourlstatbuf.st_rdev));
-      AssPRec(rec,RNamName("size"),ObjInt_Int((Int) ourlstatbuf.st_size));
-      AssPRec(rec,RNamName("blksize"),ObjInt_Int((Int)ourlstatbuf.st_blksize));
-      AssPRec(rec,RNamName("blocks"),ObjInt_Int((Int) ourlstatbuf.st_blocks));
-      AssPRec(rec,RNamName("atime"),ObjInt_Int((Int) ourlstatbuf.st_atime));
-      AssPRec(rec,RNamName("mtime"),ObjInt_Int((Int) ourlstatbuf.st_mtime));
-      AssPRec(rec,RNamName("ctime"),ObjInt_Int((Int) ourlstatbuf.st_ctime));
-      return rec;
-  }
+    }
+    return WrapStat(&ourstatbuf);
 }
 #endif
 
 #ifdef HAVE_CHMOD
-Obj FuncIO_chmod(Obj self,Obj pathname,Obj mode)
+static Obj FuncIO_chmod(Obj self,Obj pathname,Obj mode)
 {
-  Int res;
+  int res;
   if (!IS_STRING(pathname) || !IS_STRING_REP(pathname) || !IS_INTOBJ(mode)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = chmod((char *) CHARS_STRING(pathname),INT_INTOBJ(mode));
+      res = chmod(CSTR_STRING(pathname),INT_INTOBJ(mode));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -868,9 +843,9 @@ Obj FuncIO_chmod(Obj self,Obj pathname,Obj mode)
 #endif
 
 #ifdef HAVE_FCHMOD
-Obj FuncIO_fchmod(Obj self,Obj fd,Obj mode)
+static Obj FuncIO_fchmod(Obj self,Obj fd,Obj mode)
 {
-  Int res;
+  int res;
   if (!IS_INTOBJ(fd) || !IS_INTOBJ(mode)) {
       SyClearErrorNo();
       return Fail;
@@ -886,15 +861,15 @@ Obj FuncIO_fchmod(Obj self,Obj fd,Obj mode)
 #endif
 
 #ifdef HAVE_CHOWN
-Obj FuncIO_chown(Obj self,Obj path,Obj owner,Obj group)
+static Obj FuncIO_chown(Obj self,Obj path,Obj owner,Obj group)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path) ||
       !IS_INTOBJ(owner) || !IS_INTOBJ(group)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = chown((char *) CHARS_STRING(path),
+      res = chown(CSTR_STRING(path),
                   INT_INTOBJ(owner),INT_INTOBJ(group));
       if (res < 0) {
           SySetErrorNo();
@@ -906,9 +881,9 @@ Obj FuncIO_chown(Obj self,Obj path,Obj owner,Obj group)
 #endif
 
 #ifdef HAVE_FCHOWN
-Obj FuncIO_fchown(Obj self,Obj fd,Obj owner,Obj group)
+static Obj FuncIO_fchown(Obj self,Obj fd,Obj owner,Obj group)
 {
-  Int res;
+  int res;
   if (!IS_INTOBJ(fd) || !IS_INTOBJ(owner) || !IS_INTOBJ(group)) {
       SyClearErrorNo();
       return Fail;
@@ -924,15 +899,15 @@ Obj FuncIO_fchown(Obj self,Obj fd,Obj owner,Obj group)
 #endif
 
 #ifdef HAVE_LCHOWN
-Obj FuncIO_lchown(Obj self,Obj path,Obj owner,Obj group)
+static Obj FuncIO_lchown(Obj self,Obj path,Obj owner,Obj group)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path) ||
       !IS_INTOBJ(owner) || !IS_INTOBJ(group)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = lchown((char *) CHARS_STRING(path),
+      res = lchown(CSTR_STRING(path),
                    INT_INTOBJ(owner),INT_INTOBJ(group));
       if (res < 0) {
           SySetErrorNo();
@@ -944,15 +919,15 @@ Obj FuncIO_lchown(Obj self,Obj path,Obj owner,Obj group)
 #endif
 
 #ifdef HAVE_MKNOD
-Obj FuncIO_mknod(Obj self,Obj path,Obj mode,Obj dev)
+static Obj FuncIO_mknod(Obj self,Obj path,Obj mode,Obj dev)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path) ||
       !IS_INTOBJ(mode) || !IS_INTOBJ(dev)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = mknod((char *) CHARS_STRING(path),INT_INTOBJ(mode),INT_INTOBJ(dev));
+      res = mknod(CSTR_STRING(path),INT_INTOBJ(mode),INT_INTOBJ(dev));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -963,7 +938,7 @@ Obj FuncIO_mknod(Obj self,Obj path,Obj mode,Obj dev)
 #endif
 
 #ifdef HAVE_MKSTEMP
-Obj FuncIO_mkstemp(Obj self,Obj template)
+static Obj FuncIO_mkstemp(Obj self,Obj template)
 {
     Int fd;
     if (!IS_STRING(template) || !IS_STRING_REP(template)) {
@@ -971,7 +946,7 @@ Obj FuncIO_mkstemp(Obj self,Obj template)
         return Fail;
 
     } else {
-        fd = mkstemp((char *) CHARS_STRING(template));
+        fd = mkstemp(CSTR_STRING(template));
         if (fd < 0) {
             SySetErrorNo();
             return Fail;
@@ -983,36 +958,34 @@ Obj FuncIO_mkstemp(Obj self,Obj template)
 #endif
 
 #ifdef HAVE_MKDTEMP
-Obj FuncIO_mkdtemp(Obj self,Obj template)
+static Obj FuncIO_mkdtemp(Obj self,Obj template)
 {
-    Obj res;
     char *r;
 
     if (!IS_STRING(template) || !IS_STRING_REP(template)) {
         SyClearErrorNo();
         return Fail;
     } else {
-        r = mkdtemp((char *) CHARS_STRING(template));
+        r = mkdtemp(CSTR_STRING(template));
         if (r == NULL) {
             SySetErrorNo();
             return Fail;
         } else {
-            C_NEW_STRING(res, strlen(r), r);
-            return res;
+            return MakeString(r);
         }
     }
 }
 #endif
 
 #ifdef HAVE_MKFIFO
-Obj FuncIO_mkfifo(Obj self,Obj path,Obj mode)
+static Obj FuncIO_mkfifo(Obj self,Obj path,Obj mode)
 {
-  Int res;
+  int res;
   if (!IS_STRING(path) || !IS_STRING_REP(path) || !IS_INTOBJ(mode)) {
       SyClearErrorNo();
       return Fail;
   } else {
-      res = mkfifo((char *) CHARS_STRING(path),INT_INTOBJ(mode));
+      res = mkfifo(CSTR_STRING(path),INT_INTOBJ(mode));
       if (res < 0) {
           SySetErrorNo();
           return Fail;
@@ -1023,9 +996,9 @@ Obj FuncIO_mkfifo(Obj self,Obj path,Obj mode)
 #endif
 
 #ifdef HAVE_DUP
-Obj FuncIO_dup(Obj self,Obj oldfd)
+static Obj FuncIO_dup(Obj self,Obj oldfd)
 {
-  Int res;
+  int res;
   if (!IS_INTOBJ(oldfd)) {
       SyClearErrorNo();
       return Fail;
@@ -1041,9 +1014,9 @@ Obj FuncIO_dup(Obj self,Obj oldfd)
 #endif
 
 #ifdef HAVE_DUP2
-Obj FuncIO_dup2(Obj self,Obj oldfd,Obj newfd)
+static Obj FuncIO_dup2(Obj self,Obj oldfd,Obj newfd)
 {
-  Int res;
+  int res;
   if (!IS_INTOBJ(oldfd) || !IS_INTOBJ(newfd)) {
       SyClearErrorNo();
       return Fail;
@@ -1059,9 +1032,9 @@ Obj FuncIO_dup2(Obj self,Obj oldfd,Obj newfd)
 #endif
 
 #ifdef HAVE_SOCKET
-Obj FuncIO_socket(Obj self,Obj domain,Obj type,Obj protocol)
+static Obj FuncIO_socket(Obj self,Obj domain,Obj type,Obj protocol)
 {
-  Int res;
+  int res;
 #ifdef HAVE_GETPROTOBYNAME
   struct protoent *pe;
 #endif
@@ -1077,7 +1050,7 @@ Obj FuncIO_socket(Obj self,Obj domain,Obj type,Obj protocol)
   } else {
 #ifdef HAVE_GETPROTOBYNAME
       if (IS_STRING(protocol)) { /* we have to look up the protocol */
-           pe = getprotobyname((char *) CHARS_STRING(protocol));
+           pe = getprotobyname(CSTR_STRING(protocol));
            if (pe == NULL) {
                SySetErrorNo();
                return Fail;
@@ -1097,9 +1070,9 @@ Obj FuncIO_socket(Obj self,Obj domain,Obj type,Obj protocol)
 #endif
 
 #ifdef HAVE_BIND
-Obj FuncIO_bind(Obj self,Obj fd,Obj my_addr)
+static Obj FuncIO_bind(Obj self,Obj fd,Obj my_addr)
 {
-  Int res;
+  int res;
   Int len;
   if (!IS_INTOBJ(fd) || !IS_STRING(my_addr) || !IS_STRING_REP(my_addr)) {
       SyClearErrorNo();
@@ -1117,9 +1090,9 @@ Obj FuncIO_bind(Obj self,Obj fd,Obj my_addr)
 #endif
 
 #ifdef HAVE_CONNECT
-Obj FuncIO_connect(Obj self,Obj fd,Obj serv_addr)
+static Obj FuncIO_connect(Obj self,Obj fd,Obj serv_addr)
 {
-  Int res;
+  int res;
   Int len;
   if (!IS_INTOBJ(fd) || !IS_STRING(serv_addr) || !IS_STRING_REP(serv_addr)) {
       SyClearErrorNo();
@@ -1138,7 +1111,7 @@ Obj FuncIO_connect(Obj self,Obj fd,Obj serv_addr)
 #endif
 
 #ifdef HAVE_SOCKET
-Obj FuncIO_make_sockaddr_in(Obj self,Obj ip,Obj port)
+static Obj FuncIO_make_sockaddr_in(Obj self,Obj ip,Obj port)
 {
   struct sockaddr_in sa;
   Obj res;
@@ -1159,7 +1132,7 @@ Obj FuncIO_make_sockaddr_in(Obj self,Obj ip,Obj port)
 #endif
 
 #ifdef HAVE_GETHOSTBYNAME
-Obj FuncIO_gethostbyname(Obj self,Obj name)
+static Obj FuncIO_gethostbyname(Obj self,Obj name)
 {
   struct hostent *he;
   Obj res;
@@ -1172,19 +1145,19 @@ Obj FuncIO_gethostbyname(Obj self,Obj name)
       SyClearErrorNo();
       return Fail;
   } else {
-      he = gethostbyname((char *) CHARS_STRING(name));
+      he = gethostbyname(CSTR_STRING(name));
       if (he == NULL) {
           SySetErrorNo();
           return Fail;
       }
       res = NEW_PREC(0);
-      C_NEW_STRING(tmp,strlen(he->h_name),he->h_name);
+      tmp = MakeString(he->h_name);
       AssPRec(res,RNamName("name"),tmp);
       for (len = 0,p = he->h_aliases; *p != NULL ; len++, p++) ;
       tmp2 = NEW_PLIST(T_PLIST_DENSE,len);
       SET_LEN_PLIST(tmp2,len);
       for (i = 1,p = he->h_aliases; i <= len; i++,p++) {
-          C_NEW_STRING(tmp,strlen(*p),*p);
+          tmp = MakeString(*p);
           SET_ELM_PLIST(tmp2,i,tmp);
           CHANGED_BAG(tmp2);
       }
@@ -1195,7 +1168,8 @@ Obj FuncIO_gethostbyname(Obj self,Obj name)
       tmp2 = NEW_PLIST(T_PLIST_DENSE,len);
       SET_LEN_PLIST(tmp2,len);
       for (i = 1,p = he->h_addr_list; i <= len; i++,p++) {
-          C_NEW_STRING(tmp,he->h_length,*p);
+          tmp = NEW_STRING(he->h_length);
+          memcpy(CHARS_STRING(tmp), *p, he->h_length);
           SET_ELM_PLIST(tmp2,i,tmp);
           CHANGED_BAG(tmp2);
       }
@@ -1206,9 +1180,9 @@ Obj FuncIO_gethostbyname(Obj self,Obj name)
 #endif
 
 #ifdef HAVE_LISTEN
-Obj FuncIO_listen(Obj self,Obj s,Obj backlog)
+static Obj FuncIO_listen(Obj self,Obj s,Obj backlog)
 {
-  Int res;
+  int res;
   if (!IS_INTOBJ(s) || !IS_INTOBJ(backlog)) {
       SyClearErrorNo();
       return Fail;
@@ -1224,9 +1198,9 @@ Obj FuncIO_listen(Obj self,Obj s,Obj backlog)
 #endif
 
 #ifdef HAVE_ACCEPT
-Obj FuncIO_accept(Obj self,Obj fd,Obj addr)
+static Obj FuncIO_accept(Obj self,Obj fd,Obj addr)
 {
-  Int res;
+  int res;
   socklen_t len;
   if (!IS_INTOBJ(fd) || !IS_STRING(addr) || !IS_STRING_REP(addr)) {
       SyClearErrorNo();
@@ -1245,7 +1219,7 @@ Obj FuncIO_accept(Obj self,Obj fd,Obj addr)
 #endif
 
 #ifdef HAVE_RECV
-Obj FuncIO_recv(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags)
+static Obj FuncIO_recv(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags)
 {
   Int bytes;
   Int len;
@@ -1274,7 +1248,7 @@ Obj FuncIO_recv(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags)
 #endif
 
 #ifdef HAVE_RECVFROM
-Obj FuncIO_recvfrom(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
+static Obj FuncIO_recvfrom(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
                     Obj from)
 {
   Int bytes;
@@ -1291,7 +1265,7 @@ Obj FuncIO_recvfrom(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
   len = INT_INTOBJ(offset)+INT_INTOBJ(count);
   if (len > GET_LEN_STRING(st)) GrowString(st,len);
   fromlen = GET_LEN_STRING(from);
-  bytes = recvfrom(INT_INTOBJ(fd),(char *) CHARS_STRING(st)+INT_INTOBJ(offset),
+  bytes = recvfrom(INT_INTOBJ(fd),CSTR_STRING(st)+INT_INTOBJ(offset),
                    INT_INTOBJ(count),INT_INTOBJ(flags),
                    (struct sockaddr *)CHARS_STRING(from),&fromlen);
   if (bytes < 0) {
@@ -1308,7 +1282,7 @@ Obj FuncIO_recvfrom(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
 #endif
 
 #ifdef HAVE_SEND
-Obj FuncIO_send(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags)
+static Obj FuncIO_send(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags)
 {
   Int bytes;
 
@@ -1322,7 +1296,7 @@ Obj FuncIO_send(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags)
       return Fail;
   }
   bytes = (Int) send(INT_INTOBJ(fd),
-                     (char *) CHARS_STRING(st)+INT_INTOBJ(offset),
+                     CSTR_STRING(st)+INT_INTOBJ(offset),
                      INT_INTOBJ(count),INT_INTOBJ(flags));
   if (bytes < 0) {
       SySetErrorNo();
@@ -1333,7 +1307,7 @@ Obj FuncIO_send(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags)
 #endif
 
 #ifdef HAVE_SENDTO
-Obj FuncIO_sendto(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
+static Obj FuncIO_sendto(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
                   Obj to)
 {
   Int bytes;
@@ -1351,7 +1325,7 @@ Obj FuncIO_sendto(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
   }
   fromlen = GET_LEN_STRING(to);
   bytes = (Int) sendto(INT_INTOBJ(fd),
-                       (char *) CHARS_STRING(st)+INT_INTOBJ(offset),
+                       CSTR_STRING(st)+INT_INTOBJ(offset),
                        INT_INTOBJ(count),INT_INTOBJ(flags),
                        (struct sockaddr *)CHARS_STRING(to),fromlen);
   if (bytes < 0) {
@@ -1363,10 +1337,10 @@ Obj FuncIO_sendto(Obj self,Obj fd,Obj st,Obj offset,Obj count,Obj flags,
 #endif
 
 #ifdef HAVE_GETSOCKOPT
-Obj FuncIO_getsockopt(Obj self,Obj fd,Obj level,Obj optname,
+static Obj FuncIO_getsockopt(Obj self,Obj fd,Obj level,Obj optname,
                       Obj optval,Obj optlen)
 {
-  Int res;
+  int res;
   socklen_t olen;
 
   if (!IS_INTOBJ(fd) || !IS_INTOBJ(level) || !IS_INTOBJ(optname) ||
@@ -1377,7 +1351,7 @@ Obj FuncIO_getsockopt(Obj self,Obj fd,Obj level,Obj optname,
   olen = INT_INTOBJ(optlen);
   if (olen > GET_LEN_STRING(optval)) GrowString(optval,olen);
   res = (Int) getsockopt(INT_INTOBJ(fd),INT_INTOBJ(level),INT_INTOBJ(optname),
-                         (char *) CHARS_STRING(optval),&olen);
+                         CSTR_STRING(optval),&olen);
   if (res < 0) {
       SySetErrorNo();
       return Fail;
@@ -1389,9 +1363,9 @@ Obj FuncIO_getsockopt(Obj self,Obj fd,Obj level,Obj optname,
 #endif
 
 #ifdef HAVE_SETSOCKOPT
-Obj FuncIO_setsockopt(Obj self,Obj fd,Obj level,Obj optname, Obj optval)
+static Obj FuncIO_setsockopt(Obj self,Obj fd,Obj level,Obj optname, Obj optval)
 {
-  Int res;
+  int res;
   socklen_t olen;
 
   if (!IS_INTOBJ(fd) || !IS_INTOBJ(level) || !IS_INTOBJ(optname) ||
@@ -1401,7 +1375,7 @@ Obj FuncIO_setsockopt(Obj self,Obj fd,Obj level,Obj optname, Obj optval)
   }
   olen = GET_LEN_STRING(optval);
   res = (Int) setsockopt(INT_INTOBJ(fd),INT_INTOBJ(level),INT_INTOBJ(optname),
-                         (char *) CHARS_STRING(optval),olen);
+                         CSTR_STRING(optval),olen);
   if (res < 0) {
       SySetErrorNo();
       return Fail;
@@ -1411,7 +1385,7 @@ Obj FuncIO_setsockopt(Obj self,Obj fd,Obj level,Obj optname, Obj optval)
 #endif
 
 #ifdef HAVE_SELECT
-Obj FuncIO_select(Obj self, Obj inlist, Obj outlist, Obj exclist,
+static Obj FuncIO_select(Obj self, Obj inlist, Obj outlist, Obj exclist,
                   Obj timeoutsec, Obj timeoutusec)
 {
   fd_set infds,outfds,excfds;
@@ -1534,24 +1508,31 @@ Obj FuncIO_select(Obj self, Obj inlist, Obj outlist, Obj exclist,
 #endif
 
 #ifdef HAVE_FORK
-Obj FuncIO_fork(Obj self)
+static Obj FuncIO_fork(Obj self)
 {
   int res;
   FuncIO_InstallSIGCHLDHandler(0);
+  // Ensure files are flushed before forking
+  fflush(0);
   res = fork();
   if (res == -1) {
       SySetErrorNo();
       return Fail;
   }
+  #if GAP_KERNEL_MAJOR_VERSION >= 6
+  if(res == 0) {
+      /* In child */
+      InformProfilingThatThisIsAForkedGAP();
+  }
+  #endif
   return INTOBJ_INT(res);
 }
 #endif
 
-Obj FuncIO_execv(Obj self,Obj path,Obj Argv)
+static Obj FuncIO_execv(Obj self,Obj path,Obj Argv)
 {
     int argc;
     char *argv[1024];   /* Up to 1024 arguments */
-    char *envp[1024];   /* Up to 1024 environment entries */
     int i;
     Obj tmp;
 
@@ -1559,7 +1540,7 @@ Obj FuncIO_execv(Obj self,Obj path,Obj Argv)
         SyClearErrorNo();
         return Fail;
     }
-    argv[0] = (char *) CHARS_STRING(path);
+    argv[0] = CSTR_STRING(path);
     argc = LEN_PLIST(Argv);
     if (argc > 1022) {
         Pr("#E Ignored arguments after the 1022th.\n",0,0);
@@ -1571,10 +1552,10 @@ Obj FuncIO_execv(Obj self,Obj path,Obj Argv)
             SyClearErrorNo();
             return Fail;
         }
-        argv[i] = (char *) CHARS_STRING(tmp);
+        argv[i] = CSTR_STRING(tmp);
     }
     argv[i] = 0;
-    i = execv((char *) CHARS_STRING(path),argv);
+    i = execv(CSTR_STRING(path),argv);
     if (i == -1) {
         SySetErrorNo();
         return INTOBJ_INT(i);
@@ -1583,11 +1564,10 @@ Obj FuncIO_execv(Obj self,Obj path,Obj Argv)
     return Fail;
 }
 
-Obj FuncIO_execvp(Obj self,Obj file,Obj Argv)
+static Obj FuncIO_execvp(Obj self,Obj file,Obj Argv)
 {
     int argc;
     char *argv[1024];   /* Up to 1024 arguments */
-    char *envp[1024];   /* Up to 1024 environment entries */
     int i;
     Obj tmp;
 
@@ -1595,7 +1575,7 @@ Obj FuncIO_execvp(Obj self,Obj file,Obj Argv)
         SyClearErrorNo();
         return Fail;
     }
-    argv[0] = (char *) CHARS_STRING(file);
+    argv[0] = CSTR_STRING(file);
     argc = LEN_PLIST(Argv);
     if (argc > 1022) {
         Pr("#E Ignored arguments after the 1022th.\n",0,0);
@@ -1607,10 +1587,10 @@ Obj FuncIO_execvp(Obj self,Obj file,Obj Argv)
             SyClearErrorNo();
             return Fail;
         }
-        argv[i] = (char *) CHARS_STRING(tmp);
+        argv[i] = CSTR_STRING(tmp);
     }
     argv[i] = 0;
-    i = execvp((char *) CHARS_STRING(file),argv);
+    i = execvp(CSTR_STRING(file),argv);
     if (i == -1) {
         SySetErrorNo();
         return Fail;
@@ -1619,7 +1599,7 @@ Obj FuncIO_execvp(Obj self,Obj file,Obj Argv)
     return Fail;
 }
 
-Obj FuncIO_execve(Obj self,Obj path,Obj Argv,Obj Envp)
+static Obj FuncIO_execve(Obj self,Obj path,Obj Argv,Obj Envp)
 {
     int argc;
     char *argv[1024];   /* Up to 1024 arguments */
@@ -1632,7 +1612,7 @@ Obj FuncIO_execve(Obj self,Obj path,Obj Argv,Obj Envp)
         SyClearErrorNo();
         return Fail;
     }
-    argv[0] = (char *) CHARS_STRING(path);
+    argv[0] = CSTR_STRING(path);
     argc = LEN_PLIST(Argv);
     if (argc > 1022) {
         Pr("#E Ignored arguments after the 1022th.\n",0,0);
@@ -1644,7 +1624,7 @@ Obj FuncIO_execve(Obj self,Obj path,Obj Argv,Obj Envp)
             SyClearErrorNo();
             return Fail;
         }
-        argv[i] = (char *) CHARS_STRING(tmp);
+        argv[i] = CSTR_STRING(tmp);
     }
     argv[i] = 0;
     argc = LEN_PLIST(Envp);
@@ -1658,10 +1638,10 @@ Obj FuncIO_execve(Obj self,Obj path,Obj Argv,Obj Envp)
             SyClearErrorNo();
             return Fail;
         }
-        envp[i-1] = (char *) CHARS_STRING(tmp);
+        envp[i-1] = CSTR_STRING(tmp);
     }
     envp[i-1] = 0;
-    i = execve((char *) CHARS_STRING(path),argv,envp);
+    i = execve(CSTR_STRING(path),argv,envp);
     if (i == -1) {
         SySetErrorNo();
         return Fail;
@@ -1672,7 +1652,7 @@ Obj FuncIO_execve(Obj self,Obj path,Obj Argv,Obj Envp)
 
 extern char **environ;
 
-Obj FuncIO_environ(Obj self)
+static Obj FuncIO_environ(Obj self)
 {
     Int i,len;
     char **p;
@@ -1686,14 +1666,14 @@ Obj FuncIO_environ(Obj self)
     tmp2 = tmp;   /* Just to please the compiler */
     SET_LEN_PLIST(tmp2,len);
     for (i = 1, p = environ;i <= len;i++,p++) {
-        C_NEW_STRING(tmp2,strlen(*p),*p);
+        tmp2 = MakeString(*p);
         SET_ELM_PLIST(tmp,i,tmp2);
         CHANGED_BAG(tmp);
     }
     return tmp;
 }
 
-Obj FuncIO_pipe(Obj self)
+static Obj FuncIO_pipe(Obj self)
 {
     Obj tmp;
     int fds[2];
@@ -1710,7 +1690,7 @@ Obj FuncIO_pipe(Obj self)
     return tmp;
 }
 
-Obj FuncIO_exit(Obj self,Obj status)
+static Obj FuncIO_exit(Obj self,Obj status)
 {
     if (!IS_INTOBJ(status)) {
         SyClearErrorNo();
@@ -1722,46 +1702,46 @@ Obj FuncIO_exit(Obj self,Obj status)
 }
 
 #ifdef HAVE_FCNTL_H
-Obj FuncIO_fcntl(Obj self, Obj fd, Obj cmd, Obj arg)
+static Obj FuncIO_fcntl(Obj self, Obj fd, Obj cmd, Obj arg)
 {
-    Int ret;
+    int res;
     if (!IS_INTOBJ(fd) || !IS_INTOBJ(cmd) || !IS_INTOBJ(arg)) {
         SyClearErrorNo();
         return Fail;
     }
-    ret = fcntl(INT_INTOBJ(fd),INT_INTOBJ(cmd),INT_INTOBJ(arg));
-    if (ret == -1) {
+    res = fcntl(INT_INTOBJ(fd),INT_INTOBJ(cmd),INT_INTOBJ(arg));
+    if (res == -1) {
         SySetErrorNo();
         return Fail;
     } else
-        return INTOBJ_INT(ret);
+        return INTOBJ_INT(res);
 }
 #endif
 
 #ifdef HAVE_GETPID
-Obj FuncIO_getpid(Obj self)
+static Obj FuncIO_getpid(Obj self)
 {
     return INTOBJ_INT(getpid());
 }
 #endif
 
 #ifdef HAVE_GETPPID
-Obj FuncIO_getppid(Obj self)
+static Obj FuncIO_getppid(Obj self)
 {
     return INTOBJ_INT(getppid());
 }
 #endif
 
 #ifdef HAVE_KILL
-Obj FuncIO_kill(Obj self, Obj pid, Obj sig)
+static Obj FuncIO_kill(Obj self, Obj pid, Obj sig)
 {
-    Int ret;
+    int res;
     if (!IS_INTOBJ(pid) || !IS_INTOBJ(sig)) {
         SyClearErrorNo();
         return Fail;
     }
-    ret = kill((pid_t) INT_INTOBJ(pid),(int) INT_INTOBJ(sig));
-    if (ret == -1) {
+    res = kill((pid_t) INT_INTOBJ(pid),(int) INT_INTOBJ(sig));
+    if (res == -1) {
         SySetErrorNo();
         return Fail;
     } else
@@ -1770,7 +1750,7 @@ Obj FuncIO_kill(Obj self, Obj pid, Obj sig)
 #endif
 
 #ifdef HAVE_GETTIMEOFDAY
-Obj FuncIO_gettimeofday( Obj self )
+static Obj FuncIO_gettimeofday( Obj self )
 {
    Obj tmp;
    struct timeval tv;
@@ -1783,7 +1763,7 @@ Obj FuncIO_gettimeofday( Obj self )
 #endif
 
 #ifdef HAVE_GMTIME
-Obj FuncIO_gmtime( Obj self, Obj time )
+static Obj FuncIO_gmtime( Obj self, Obj time )
 {
     Obj tmp;
     time_t t;
@@ -1810,7 +1790,7 @@ Obj FuncIO_gmtime( Obj self, Obj time )
 #endif
 
 #ifdef HAVE_LOCALTIME
-Obj FuncIO_localtime( Obj self, Obj time )
+static Obj FuncIO_localtime( Obj self, Obj time )
 {
     Obj tmp;
     time_t t;
@@ -1837,7 +1817,7 @@ Obj FuncIO_localtime( Obj self, Obj time )
 #endif
 
 #ifdef HAVE_GETSOCKNAME
-Obj FuncIO_getsockname(Obj self, Obj fd)
+static Obj FuncIO_getsockname(Obj self, Obj fd)
 {
   struct sockaddr_in sa;
   socklen_t sa_len;
@@ -1856,7 +1836,7 @@ Obj FuncIO_getsockname(Obj self, Obj fd)
 #endif
 
 #ifdef HAVE_GETHOSTNAME
-Obj FuncIO_gethostname(Obj self)
+static Obj FuncIO_gethostname(Obj self)
 {
   char name[256];
   Obj res;
